<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX Network Assistant</source>
        <translation>MX Pomocník se sítí</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>IP address</source>
        <translation>IP adresa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Hardware detected</source>
        <translation>Nalezen hardware</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Enable</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <location filename="../mainwindow.ui" line="603"/>
        <location filename="../mainwindow.ui" line="712"/>
        <source>Re-scan</source>
        <translation>Znovu vyhledat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>Enabled</source>
        <translation>Zapnuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>Driver</source>
        <translation>Ovladač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>Vendor</source>
        <translation>Výrobce</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Product</source>
        <translation>Produkt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Disable</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Active interface</source>
        <translation>Aktivní rozhraní</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>WiFi status</source>
        <translation>WiFi status</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Odblokuje všechny blokované bezdrátové zařízení</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>Unblock WiFi Devices</source>
        <translation>Odblokovat WiFi </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Linux drivers</source>
        <translation>Ovladače Linuxu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>Associated Linux drivers</source>
        <translation>Přiřazené ovladače Linuxu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Load Driver</source>
        <translation>Načist ovladač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>Unload Driver</source>
        <translation>Uvolnit ovladač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="622"/>
        <location filename="../mainwindow.cpp" line="833"/>
        <source>Block Driver</source>
        <translation>Zakázat ovladač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="640"/>
        <source>Windows drivers</source>
        <translation>Windows ovladače</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="646"/>
        <source>Available Windows drivers</source>
        <translation>Dostupné Windows ovladače</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Remove Driver</source>
        <translation>Odstranit ovladač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="690"/>
        <source>Add Driver</source>
        <translation>Přidat ovladač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="729"/>
        <source>About NDISwrapper</source>
        <translation>O programu NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="741"/>
        <source>Install NDISwrapper</source>
        <translation>Instalovat NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="751"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Za účelem možnosti použití ovladačů Windows musíte nejdřív nainstalovat NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="767"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Odinstalovat NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>Net diagnostics</source>
        <translation>Diagnostika sítě</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="810"/>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <location filename="../mainwindow.ui" line="933"/>
        <source>Target URL:</source>
        <translation>Cílové URL:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="826"/>
        <source>Packets</source>
        <translation>Pakety</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <location filename="../mainwindow.ui" line="991"/>
        <source>Start</source>
        <translation>Spustit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="1007"/>
        <source>Clear</source>
        <translation>Vyčistit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <location filename="../mainwindow.ui" line="1020"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="927"/>
        <source>Traceroute</source>
        <translation>Traceroute</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="943"/>
        <source>Hops</source>
        <translation>Hops</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>IP address from router:</source>
        <translation>IP adresa z routru:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>External IP address:</source>
        <translation>Externí IP adresa:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>Interface: %1</source>
        <translation>Interface: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>Driver: %1</source>
        <translation>Ovladač: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Description: %1</source>
        <translation>Popis: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>Product: %1</source>
        <translation>Produkt: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <source>Vendor: %1</source>
        <translation>Výrobce: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Enabled: %1</source>
        <translation>Zapnuto: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <location filename="../mainwindow.cpp" line="209"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="211"/>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Copy &amp;All</source>
        <translation>Kopírovat &amp;vše</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Traceroute not installed</source>
        <translation>Traceroute není nainstalován</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>Traceroute není nainstalován, přejete si ho nainstalovat?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>Traceroute nebyl nainstalován</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Traceroute nemůže být nainstalován. Může to být způsobeno tím, že používáte LiveCD nebo nemáte přístup k softvérovým repozitářům.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>Traceroute není nainstalován a nebylo rozpoznáno žádné připojení k Internetu, bez kterého nelze program nainstalovat.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>No destination host</source>
        <translation>Žádný cílový host</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Please fill in the destination host field</source>
        <translation>Prosím vyplňte políčko cílový host</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>Loaded Drivers</source>
        <translation>Načtené ovladače</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>Unloaded Drivers</source>
        <translation>Nenačtené ovladače</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Blocked Drivers</source>
        <translation>Zakázané ovladače</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Blocked Broadcom Drivers</source>
        <translation>Zakázané ovladače Mobilního připojení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Ndiswrapper is not installed</source>
        <translation>NDISwrapper není nainstalován</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>driver installed</source>
        <translation>Ovladač nainstalován</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source> and in use by </source>
        <translation>a používán</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>. Alternate driver: </source>
        <translation>. Alternativní ovladač:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist</source>
        <translation>Ovladač byl odstraněn se seznamu zakázaných</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist.</source>
        <translation>Ovladač byl odstraněn se seznamu zakázaných</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>Module blocked</source>
        <translation>Modul byl zakázán</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Installation successful</source>
        <translation>Instalace úspěšná</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>Chyba, není možné zkompilovat ovladač NDISwrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="768"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>Chyba, není možné nainstalovat NDISwrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="780"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>Počas odstraňování NDISwrapper se vyskytly chyby</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>Unblock Driver</source>
        <translation>Povolit ovladač</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>enabled</source>
        <translation>povoleno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="865"/>
        <source>disabled</source>
        <translation>zakázáno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="868"/>
        <source>WiFi hardware switch is off</source>
        <translation>Hardvérový přepínač WiFi je v poloze vypnuto.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Určit ovladač z Windows, který si přejete přidat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>Windows installation information file (*.inf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>*.sys file not found</source>
        <translation>sobor *.sys nenalezen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>Soubory *.sys musí být umístněny v stejné složce jako soubor *.inf. %1 nelze nalézt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="919"/>
        <source>sys file reference not found</source>
        <translation>referene soboru *.sys nenalezena</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="920"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>Po zanalyzování inf souboru nemůže být určen sys soubor daného ovladače</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="937"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>Ovladač Ndiswrapper odstraněn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>%1 Help</source>
        <translation>Nápověda %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="957"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Nebylo možné odblokovat zařízení.
Zařízení WiFi by už mohlo být odblokováno(y).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="959"/>
        <source>WiFi devices unlocked.</source>
        <translation>WiFi zařízení odblokovány.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>About %1</source>
        <translation>O programu %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="975"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>Program for troubleshooting and configuring network for MX Linux</source>
        <translation>Program pro řešení problémů a nastavení sítě pro MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="978"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Vlastnická práva (c) MEPIS LLC a MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="979"/>
        <source>%1 License</source>
        <translation>Licence %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1005"/>
        <source>Driver loaded successfully</source>
        <translation>Ovladač byl úspěšně načten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1020"/>
        <source>Driver unloaded successfully</source>
        <translation>Ovladač byl úspěšně uvolněn</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Protokol změn</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <location filename="../main.cpp" line="78"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Spuštěno pod účtem root-a, odhlašte se a přihlašte jako bězný uživatel.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program with admin access.</source>
        <translation>Tento program musíte spustit s oprávněním správce.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Could not load </source>
        <translation>Nelze načíst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Could not unload </source>
        <translation>Nelze uvolnit</translation>
    </message>
</context>
</TS>